Kinship82: Rosenberg-Kim Kinship Terms Partition Data

Kinship82R Documentation

Rosenberg-Kim Kinship Terms Partition Data

Description

Partitions of 15 kinship terms given by 85 female undergraduates at Rutgers University who were asked to sort the terms into classes “on the basis of some aspect of meaning”.

Usage

data("Kinship82")

Format

A cluster ensemble of 85 hard partitions of the 15 kinship terms.

Details

\bibcitet

Rosenberg+Kim:1975 describe an experiment where perceived similarities of the kinship terms were obtained from six different “sorting” experiments. These “original” Rosenberg-Kim kinship terms data were published in \bibcitetArabie+Carroll+DeSarbo:1987, and are also contained in file ‘indclus.data’ in the shell archive https://netlib.org/mds/indclus.shar.

For one of the experiments, partitions of the terms were printed in \bibcitetRosenberg:1982. Comparison with the original data indicates that the partition data have the “nephew” and “niece” columns interchanged, which is corrected in the data set at hand.

Table 7.1 in \bibcitetRosenberg:1982, with the “nephew” and “niece” columns interchanged.

References

\bibshow

Arabie+Carroll+DeSarbo:1987, Rosenberg+Kim:1975, Rosenberg:1982


clue documentation built on Feb. 18, 2026, 5:06 p.m.