Learn R Programming

clue (version 0.3-67)

Kinship82_Consensus: Gordon-Vichi Kinship82 Consensus Partition Data

Description

The soft (“fuzzy”) consensus partitions for the Rosenberg-Kim kinship terms partition data given in Gordon+Vichi:2001.

Usage

data("Kinship82_Consensus")

Arguments

Format

A named cluster ensemble of three soft partitions of the 15 kinship terms into three classes.

Details

The elements of the ensemble are named "MF1", "MF2", and "JMF", and correspond to the consensus partitions obtained by applying models 1, 2, and 3 in Gordon+Vichi:2001 to the kinship terms partition data in Rosenberg:1982, which are available as data set Kinship82.

References

Gordon+Vichi:2001, Rosenberg:1982

Examples

Run this code
## Load the consensus partitions.
data("Kinship82_Consensus")
## Fuzziness using the Partition Coefficient.
cl_fuzziness(Kinship82_Consensus)
## (Corresponds to 1 - F in the source.)
## Dissimilarities:
cl_dissimilarity(Kinship82_Consensus)
cl_dissimilarity(Kinship82_Consensus, method = "comem")

Run the code above in your browser using DataLab