If y is given, its components must be of the same kind as those
of x (i.e., components must either all be partitions, or all be
hierarchies or dissimilarities). If all components are partitions, the following built-in methods for
measuring dissimilarity between two partitions with respective
membership matrices $u$ and $v$ (brought to a common number of
columns) are available:
[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object]
For hard partitions, both Manhattan and squared Euclidean
dissimilarity give twice the transfer distance (Charon et al.,
2005), which is the minimum number of objects that must be removed so
that the implied partitions (restrictions to the remaining objects)
are identical. This is also known as the $R$-metric in Day
(1981), i.e., the number of augmentations and removals of single
objects needed to transform one partition into the other, and the
partition-distance in Gusfield (2002), and equals twice the
number of single element moves distance of Boorman and Arabie.
If all components are hierarchies, available built-in methods for
measuring dissimilarity between two hierarchies with respective
ultrametrics $u$ and $v$ are as follows.
[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object]
The measures based on ultrametrics also allow computing dissimilarity
with raw dissimilarities on the underlying objects (R objects
inheriting from class "dist").
If a user-defined agreement method is to be employed, it must be a
function taking two clusterings as its arguments.
Symmetric dissimilarity objects of class "cl_dissimilarity" are
implemented as symmetric proximity objects with self-proximities
identical to zero, and inherit from class "cl_proximity". They
can be coerced to dense square matrices using as.matrix. It
is possible to use 2-index matrix-style subscripting for such objects;
unless this uses identical row and column indices, this results in a
(non-symmetric dissimilarity) object of class
"cl_cross_dissimilarity".
Symmetric dissimilarity objects also inherit from class
"dist" (although they currently do not strictly
extend this class), thus making it possible to use them directly for
clustering algorithms based on dissimilarity matrices of this class,
see the examples.