l1_fit_ultrametric(x, method = c("SUMT", "IRIP"), weights = 1,
control = list())"dist"."SUMT" (default) or "IRIP",
or a unique abbreviation thereof.x, and the lower diagonal part is used.
"cl_ultrametric" containing the
fitted ultrametric distances.We provide two heuristics for solving this problem.
Method "SUMT" implements a SUMT (Sequential
Unconstrained Minimization Technique, see sumt) approach
using the sign function for the gradients of the absolute value
function.
Available control parameters are method, control,
eps, q, and verbose, which have the same roles as
for sumt, and the following.
[object Object],[object Object]
Method "IRIP" implements a variant of the Iteratively
Reweighted Iterative Projection approach of Smith (2001), which
attempts to solve the $L_1$ problem via a sequence of weighted
$L_2$ problems, determining $u(t+1)$ by minimizing the
criterion function
$$\sum_{i,j} w_{ij}
(x_{ij} - u_{ij})^2 / \max(|x_{ij} - u_{ij}(t)|, m)$$
with $m$ a ls_fit_ultrametric
for solving the weighted least squares problems.
Available control parameters are as follows. [object Object],[object Object],[object Object],[object Object],[object Object],[object Object] One may need to adjust the default control parameters to achieve convergence.
It should be noted that all methods are heuristics which can not be guaranteed to find the global minimum.
T. J. Smith (2001). Constructing ultrametric and additive trees based on the $L_1$ norm. Journal of Classification, 18, 185--207.
cl_consensus for computing least absolute deviation
(Manhattan) consensus hierarchies;
ls_fit_ultrametric.