ls_fit_sum_of_ultrametrics(x, nterms = 1, weights = 1, control = list())"dist".x, and the lower diagonal part is used.
Otherwise, it is recycled to the number of elements in x."cl_ultrametric" containing
the fitted ultrametric distances.
We provide an implementation of the iterative heuristic suggested in
Carroll & Pruzansky (1980) which in each step $t$ sequentially
refits the $u(k)$ as the least squares ultrametric fit to the
residuals $x - \sum_{l \ne k} u(l)$ using
ls_fit_ultrametric.
Available control parameters include
maxiter
epseps.
Defaults to $10^{-6}$.
reltolreltol.
Defaults to $10^{-6}$.
method
controlls_fit_ultrametric employed. By default,
if the SUMT method method is used, 10 inner
SUMT runs are performed for each refitting.
It should be noted that the method used is a heuristic which can not be guaranteed to find the global minimum.