| GVME_Consensus | R Documentation |
The soft (“fuzzy”) consensus partitions for the macroeconomic partition data given in \bibcitetGordon+Vichi:2001.
data("GVME_Consensus")
A named cluster ensemble of eight soft partitions of 21 countries terms into two or three classes.
The elements of the ensemble are consensus partitions for the
macroeconomic partition data in \bibcitetGordon+Vichi:2001, which are
available as data set GVME. Element names are of the
form "m/k", where m indicates the consensus
method employed (one of ‘MF1’, ‘MF2’, ‘JMF’, and
‘S&S’, corresponding to the application of models 1, 2, and 3
in \bibcitetGordon+Vichi:2001 and the approach in
\bibcitetSato+Sato:1994,
respectively), and k denotes the number classes (2 or 3).
Tables 4 and 5 in \bibcitetGordon+Vichi:2001.
Gordon+Vichi:2001, Sato+Sato:1994
## Load the consensus partitions.
data("GVME_Consensus")
## Pick the partitions into 2 classes.
GVME_Consensus_2 <- GVME_Consensus[1 : 4]
## Fuzziness using the Partition Coefficient.
cl_fuzziness(GVME_Consensus_2)
## (Corresponds to 1 - F in the source.)
## Dissimilarities:
cl_dissimilarity(GVME_Consensus_2)
cl_dissimilarity(GVME_Consensus_2, method = "comem")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.