| cl_pam | R Documentation |
Compute k-medoids partitions of clusterings.
cl_pam(x, k, method = "euclidean", solver = c("pam", "kmedoids"))
x |
an ensemble of partitions or hierarchies, or something
coercible to that (see |
k |
an integer giving the number of classes to be used in the partition. |
method |
a character string or a function, as for argument
|
solver |
a character string indicating the |
An optimal k-medoids partition of the given cluster ensemble is
defined as a partition of the objects x_i (the elements of the
ensemble) into k classes C_1, \ldots, C_k such that the
criterion function
L = \sum_{l=1}^k \min_{j \in C_l} \sum_{i \in C_l} d(x_i, x_j)
is minimized.
Such secondary partitions \bibcitepe.g.|Gordon+Vichi:1998|
are obtained by
computing the dissimilarities d of the objects in the ensemble
for the given dissimilarity method, and applying a dissimilarity-based
k-medoids solver to d.
An object of class "cl_pam" representing the obtained
“secondary” partition, which is a list with the following
components.
cluster |
the class ids of the partition. |
medoid_ids |
the indices of the medoids. |
prototypes |
a cluster ensemble with the |
criterion |
the value of the criterion function of the partition. |
description |
a character string indicating the dissimilarity method employed. |
Kaufman+Rousseeuw:1990, Gordon+Vichi:1998
cl_pclust for more general prototype-based partitions of
clusterings.
data("Kinship82")
party <- cl_pam(Kinship82, 3, "symdiff")
## Compare results with tables 5 and 6 in Gordon & Vichi (1998).
party
lapply(cl_prototypes(party), cl_classes)
table(cl_class_ids(party))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.